==> estateplat-common-1.2.3-20180115.084831-14-sources.jar: cn/gtmap/estateplat/model/stockHouse/contract/LsFcjyClfMmht.java <==
package cn.gtmap.estateplat.model.stockHouse.contract;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2017-9-19
 * @description 存量房买卖合同属性结构描述表
 */
@Table(name = "ls_fcjy_clf_mmht")
public class LsFcjyClfMmht implements InsertVo {
    @Id
    private String htid;//合同id
    private String yhtid;//合同id
    private Long yhtbh;//合同编号
    private String cqzh;//产权证号
    private String hbh;//户编号
    private String fwzl;//房屋坐落
    private String fwlx;//房屋类型
    private String fwjg;//房屋结构
    private String hx;//户型
    private Double jzmj;//建筑面积
    private Double tnjzmj;//套内建筑面积
    private Double jg;//价格
    private String htbz;//合同币种
    private String fklx;//付款类型
    private String dkfs;//贷款方式
    private Date fksj;//付款时间
    private Date qdrq;//签订日期
    private Date qrsj;//确认时间
    private Date qrqzsj;//确认签字时间
    private Date zhbgtgsj;//最后变更通过时间
    private Date cxsj;//撤销时间
    private Date jssj;//结束时间
    private String zt;//状态
    private String sfyx;//是否有效
    private String wqrxm;//网签人姓名
    private String bdcdjblzt;//不动产登记办理状态
    private Date barq;//备案日期
    private String cxyy;//撤销原因
    private String htdyzt;//合同打印状态
    private String czr;//操作人
    private Date czsj;//操作时间
    private String czyy;//操作原因
    private String czlx;//操作类型

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getYhtid() {
        return yhtid;
    }

    public void setYhtid(String yhtid) {
        this.yhtid = yhtid;
    }

    public Long getYhtbh() {
        return yhtbh;
    }

    public void setYhtbh(Long yhtbh) {
        this.yhtbh = yhtbh;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public String getHbh() {
        return hbh;
    }

    public void setHbh(String hbh) {
        this.hbh = hbh;
    }

    public String getFwzl() {
        return fwzl;
    }

    public void setFwzl(String fwzl) {
        this.fwzl = fwzl;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public String getHx() {
        return hx;
    }

    public void setHx(String hx) {
        this.hx = hx;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getTnjzmj() {
        return tnjzmj;
    }

    public void setTnjzmj(Double tnjzmj) {
        this.tnjzmj = tnjzmj;
    }

    public Double getJg() {
        return jg;
    }

    public void setJg(Double jg) {
        this.jg = jg;
    }

    public String getHtbz() {
        return htbz;
    }

    public void setHtbz(String htbz) {
        this.htbz = htbz;
    }

    public String getFklx() {
        return fklx;
    }

    public void setFklx(String fklx) {
        this.fklx = fklx;
    }

    public String getDkfs() {
        return dkfs;
    }

    public void setDkfs(String dkfs) {
        this.dkfs = dkfs;
    }

    public Date getFksj() {
        return fksj;
    }

    public void setFksj(Date fksj) {
        this.fksj = fksj;
    }

    public Date getQdrq() {
        return qdrq;
    }

    public void setQdrq(Date qdrq) {
        this.qdrq = qdrq;
    }

    public Date getQrsj() {
        return qrsj;
    }

    public void setQrsj(Date qrsj) {
        this.qrsj = qrsj;
    }

    public Date getQrqzsj() {
        return qrqzsj;
    }

    public void setQrqzsj(Date qrqzsj) {
        this.qrqzsj = qrqzsj;
    }

    public Date getZhbgtgsj() {
        return zhbgtgsj;
    }

    public void setZhbgtgsj(Date zhbgtgsj) {
        this.zhbgtgsj = zhbgtgsj;
    }

    public Date getCxsj() {
        return cxsj;
    }

    public void setCxsj(Date cxsj) {
        this.cxsj = cxsj;
    }

    public Date getJssj() {
        return jssj;
    }

    public void setJssj(Date jssj) {
        this.jssj = jssj;
    }

    public String getZt() {
        return zt;
    }

    public void setZt(String zt) {
        this.zt = zt;
    }

    public String getSfyx() {
        return sfyx;
    }

    public void setSfyx(String sfyx) {
        this.sfyx = sfyx;
    }

    public String getWqrxm() {
        return wqrxm;
    }

    public void setWqrxm(String wqrxm) {
        this.wqrxm = wqrxm;
    }

    public String getBdcdjblzt() {
        return bdcdjblzt;
    }

    public void setBdcdjblzt(String bdcdjblzt) {
        this.bdcdjblzt = bdcdjblzt;
    }

    public Date getBarq() {
        return barq;
    }

    public void setBarq(Date barq) {
        this.barq = barq;
    }

    public String getCxyy() {
        return cxyy;
    }

    public void setCxyy(String cxyy) {
        this.cxyy = cxyy;
    }

    public String getHtdyzt() {
        return htdyzt;
    }

    public void setHtdyzt(String htdyzt) {
        this.htdyzt = htdyzt;
    }

    public String getCzr() {
        return czr;
    }

    public void setCzr(String czr) {
        this.czr = czr;
    }

    public Date getCzsj() {
        return czsj;
    }

    public void setCzsj(Date czsj) {
        this.czsj = czsj;
    }

    public String getCzyy() {
        return czyy;
    }

    public void setCzyy(String czyy) {
        this.czyy = czyy;
    }

    public String getCzlx() {
        return czlx;
    }

    public void setCzlx(String czlx) {
        this.czlx = czlx;
    }
}

==> estateplat-common-1.2.3-20190301.025841-228-sources.jar: cn/gtmap/estateplat/model/stockHouse/contract/LsFcjyClfMmht.java <==
package cn.gtmap.estateplat.model.stockHouse.contract;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2017-9-19
 * @description 存量房买卖合同属性结构描述表
 */
@Table(name = "ls_fcjy_clf_mmht")
public class LsFcjyClfMmht implements InsertVo {
    @Id
    private String htid;//合同id
    private String yhtid;//合同id
    private Long yhtbh;//合同编号
    private String mbid;//模版id
    private String cqzh;//产权证号
    private String hbh;//户编号
    private String fwzl;//房屋坐落
    private String fwlx;//房屋类型
    private String fwjg;//房屋结构
    private String hx;//户型
    private Double jzmj;//建筑面积
    private Double tnjzmj;//套内建筑面积
    private Double jg;//价格
    private String htbz;//合同币种
    private String fklx;//付款类型
    private String dkfs;//贷款方式
    private Date fksj;//付款时间
    private Date qdrq;//签订日期
    private Date qrsj;//确认时间
    private Date qrqzsj;//确认签字时间
    private Date zhbgtgsj;//最后变更通过时间
    private Date cxsj;//撤销时间
    private Date jssj;//结束时间
    private String zt;//状态
    private String sfyx;//是否有效
    private String wqrxm;//网签人姓名
    private String bdcdjblzt;//不动产登记办理状态
    private Date barq;//备案日期
    private String cxyy;//撤销原因
    private String htdyzt;//合同打印状态
    private String czr;//操作人
    private Date czsj;//操作时间
    private String czyy;//操作原因
    private String czlx;//操作类型

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getYhtid() {
        return yhtid;
    }

    public void setYhtid(String yhtid) {
        this.yhtid = yhtid;
    }

    public Long getYhtbh() {
        return yhtbh;
    }

    public void setYhtbh(Long yhtbh) {
        this.yhtbh = yhtbh;
    }

    public String getMbid() {
        return mbid;
    }

    public void setMbid(String mbid) {
        this.mbid = mbid;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public String getHbh() {
        return hbh;
    }

    public void setHbh(String hbh) {
        this.hbh = hbh;
    }

    public String getFwzl() {
        return fwzl;
    }

    public void setFwzl(String fwzl) {
        this.fwzl = fwzl;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public String getHx() {
        return hx;
    }

    public void setHx(String hx) {
        this.hx = hx;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getTnjzmj() {
        return tnjzmj;
    }

    public void setTnjzmj(Double tnjzmj) {
        this.tnjzmj = tnjzmj;
    }

    public Double getJg() {
        return jg;
    }

    public void setJg(Double jg) {
        this.jg = jg;
    }

    public String getHtbz() {
        return htbz;
    }

    public void setHtbz(String htbz) {
        this.htbz = htbz;
    }

    public String getFklx() {
        return fklx;
    }

    public void setFklx(String fklx) {
        this.fklx = fklx;
    }

    public String getDkfs() {
        return dkfs;
    }

    public void setDkfs(String dkfs) {
        this.dkfs = dkfs;
    }

    public Date getFksj() {
        return fksj;
    }

    public void setFksj(Date fksj) {
        this.fksj = fksj;
    }

    public Date getQdrq() {
        return qdrq;
    }

    public void setQdrq(Date qdrq) {
        this.qdrq = qdrq;
    }

    public Date getQrsj() {
        return qrsj;
    }

    public void setQrsj(Date qrsj) {
        this.qrsj = qrsj;
    }

    public Date getQrqzsj() {
        return qrqzsj;
    }

    public void setQrqzsj(Date qrqzsj) {
        this.qrqzsj = qrqzsj;
    }

    public Date getZhbgtgsj() {
        return zhbgtgsj;
    }

    public void setZhbgtgsj(Date zhbgtgsj) {
        this.zhbgtgsj = zhbgtgsj;
    }

    public Date getCxsj() {
        return cxsj;
    }

    public void setCxsj(Date cxsj) {
        this.cxsj = cxsj;
    }

    public Date getJssj() {
        return jssj;
    }

    public void setJssj(Date jssj) {
        this.jssj = jssj;
    }

    public String getZt() {
        return zt;
    }

    public void setZt(String zt) {
        this.zt = zt;
    }

    public String getSfyx() {
        return sfyx;
    }

    public void setSfyx(String sfyx) {
        this.sfyx = sfyx;
    }

    public String getWqrxm() {
        return wqrxm;
    }

    public void setWqrxm(String wqrxm) {
        this.wqrxm = wqrxm;
    }

    public String getBdcdjblzt() {
        return bdcdjblzt;
    }

    public void setBdcdjblzt(String bdcdjblzt) {
        this.bdcdjblzt = bdcdjblzt;
    }

    public Date getBarq() {
        return barq;
    }

    public void setBarq(Date barq) {
        this.barq = barq;
    }

    public String getCxyy() {
        return cxyy;
    }

    public void setCxyy(String cxyy) {
        this.cxyy = cxyy;
    }

    public String getHtdyzt() {
        return htdyzt;
    }

    public void setHtdyzt(String htdyzt) {
        this.htdyzt = htdyzt;
    }

    public String getCzr() {
        return czr;
    }

    public void setCzr(String czr) {
        this.czr = czr;
    }

    public Date getCzsj() {
        return czsj;
    }

    public void setCzsj(Date czsj) {
        this.czsj = czsj;
    }

    public String getCzyy() {
        return czyy;
    }

    public void setCzyy(String czyy) {
        this.czyy = czyy;
    }

    public String getCzlx() {
        return czlx;
    }

    public void setCzlx(String czlx) {
        this.czlx = czlx;
    }
}
